window.Gleam.initSearch([{"doc":"nibble","title":"nibble","content":"# nibble\n\n[![Package Version](https://img.shields.io/hexpm/v/nibble)](https://hex.pm/packages/nibble)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/nibble/)\n\nA string parsing library heavily inspired by [`elm/parser`](https://github.com/elm/parser).\n\n## Quick start\n\n```gleam\nimport gleam/function\nimport nibble.{ Parser }\n\ntype Point {\n    Point(x: Int, y: Int)\n}\n\npub fn main () {\n    let parser = \n        nibble.succeed(function.curry2(Point))\n            |&gt; nibble.drop(nibble.grapheme(&quot;(&quot;))\n            |&gt; nibble.drop(nibble.spaces())\n            |&gt; nibble.keep(nibble.int())\n            |&gt; nibble.drop(nibble.spaces())\n            |&gt; nibble.drop(nibble.grapheme(&quot;,&quot;))\n            |&gt; nibble.drop(nibble.spaces())\n            |&gt; nibble.keep(nibble.int())\n            |&gt; nibble.drop(nibble.spaces())\n            |&gt; nibble.drop(nibble.grapheme(&quot;)&quot;))\n\n    assert Ok(point) = nibble.run(&quot;(1, 2)&quot;, parser)\n\n    point.x //=&gt; 1\n    point.y //=&gt; 2\n}\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add nibble\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/nibble&gt;.\n","url":"index.html"},{"doc":"nibble/predicates","title":"is_alphanum","content":"pub fn is_alphanum(grapheme: String) -&gt; Bool\n\nSynonyms:\nnibble/predicates.is_alphanum\nnibble/predicates is_alphanum","url":"nibble/predicates.html#is_alphanum"},{"doc":"nibble/predicates","title":"is_digit","content":"pub fn is_digit(grapheme: String) -&gt; Bool\n\nSynonyms:\nnibble/predicates.is_digit\nnibble/predicates is_digit","url":"nibble/predicates.html#is_digit"},{"doc":"nibble/predicates","title":"is_lower","content":"pub fn is_lower(grapheme: String) -&gt; Bool\n\nSynonyms:\nnibble/predicates.is_lower\nnibble/predicates is_lower","url":"nibble/predicates.html#is_lower"},{"doc":"nibble/predicates","title":"is_upper","content":"pub fn is_upper(grapheme: String) -&gt; Bool\n\nSynonyms:\nnibble/predicates.is_upper\nnibble/predicates is_upper","url":"nibble/predicates.html#is_upper"},{"doc":"nibble/predicates","title":"is_whitespace","content":"pub fn is_whitespace(grapheme: String) -&gt; Bool\n\nSynonyms:\nnibble/predicates.is_whitespace\nnibble/predicates is_whitespace","url":"nibble/predicates.html#is_whitespace"},{"doc":"nibble/predicates","title":"nibble/predicates","content":"","url":"nibble/predicates.html"},{"doc":"nibble","title":"DeadEnd","content":"pub type DeadEnd(ctx) {\n  DeadEnd(\n    row: Int,\n    col: Int,\n    problem: Error,\n    context: List(Located(ctx)),\n  )\n}\n\nDeadEnd(\n  row: Int,\n  col: Int,\n  problem: Error,\n  context: List(Located(ctx)),\n)\n\n\nSynonyms:\nnibble.DeadEnd\nnibble DeadEnd","url":"nibble.html#DeadEnd"},{"doc":"nibble","title":"Error","content":"pub type Error {\n  BadParser(String)\n  Custom(String)\n  EndOfInput\n  Expected(String, got: String)\n  Unexpected(String)\n}\n\nBadParser(String)\n\n\nCustom(String)\n\n\nEndOfInput\n\n\nExpected(String, got: String)\n\n\nUnexpected(String)\n\n\nSynonyms:\nnibble.Error\nnibble Error","url":"nibble.html#Error"},{"doc":"nibble","title":"Located","content":"pub type Located(ctx) {\n  Located(row: Int, col: Int, context: ctx)\n}\n\nLocated(row: Int, col: Int, context: ctx)\n\n\nSynonyms:\nnibble.Located\nnibble Located","url":"nibble.html#Located"},{"doc":"nibble","title":"Loop","content":"pub type Loop(a, state) {\n  Continue(state)\n  Break(a)\n}\n\nContinue(state)\n\n\nBreak(a)\n\n\nSynonyms:\nnibble.Loop\nnibble Loop","url":"nibble.html#Loop"},{"doc":"nibble","title":"Parser","content":"pub opaque type Parser(a, ctx)\n\n\nSynonyms:\nnibble.Parser\nnibble Parser","url":"nibble.html#Parser"},{"doc":"nibble","title":"any","content":"pub fn any() -&gt; Parser(String, a)\n\nSynonyms:\nnibble.any\nnibble any","url":"nibble.html#any"},{"doc":"nibble","title":"backtrackable","content":"pub fn backtrackable(parser: Parser(a, b)) -&gt; Parser(a, b)\n\nSynonyms:\nnibble.backtrackable\nnibble backtrackable","url":"nibble.html#backtrackable"},{"doc":"nibble","title":"commit","content":"pub fn commit(to a: a) -&gt; Parser(a, b)\n\nSynonyms:\nnibble.commit\nnibble commit","url":"nibble.html#commit"},{"doc":"nibble","title":"drop","content":"pub fn drop(parse_a: Parser(a, b), parse_x: Parser(c, b)) -&gt; Parser(\n  a,\n  b,\n)\n\nSynonyms:\nnibble.drop\nnibble drop","url":"nibble.html#drop"},{"doc":"nibble","title":"eof","content":"pub fn eof() -&gt; Parser(Nil, a)\n\nSynonyms:\nnibble.eof\nnibble eof","url":"nibble.html#eof"},{"doc":"nibble","title":"fail","content":"pub fn fail(message: String) -&gt; Parser(a, b)\n\nSynonyms:\nnibble.fail\nnibble fail","url":"nibble.html#fail"},{"doc":"nibble","title":"float","content":"pub fn float() -&gt; Parser(Float, a)\n\nSynonyms:\nnibble.float\nnibble float","url":"nibble.html#float"},{"doc":"nibble","title":"grapheme","content":"pub fn grapheme(str: String) -&gt; Parser(Nil, a)\n\nSynonyms:\nnibble.grapheme\nnibble grapheme","url":"nibble.html#grapheme"},{"doc":"nibble","title":"in","content":"pub fn in(parser: Parser(a, b), context: b) -&gt; Parser(a, b)\n\nSynonyms:\nnibble.in\nnibble in","url":"nibble.html#in"},{"doc":"nibble","title":"inspect","content":"pub fn inspect(parser: Parser(a, b), message: String) -&gt; Parser(\n  a,\n  b,\n)\n Run the given parser and then inspect it&#39;s state. \nSynonyms:\nnibble.inspect\nnibble inspect","url":"nibble.html#inspect"},{"doc":"nibble","title":"int","content":"pub fn int() -&gt; Parser(Int, a)\n\nSynonyms:\nnibble.int\nnibble int","url":"nibble.html#int"},{"doc":"nibble","title":"keep","content":"pub fn keep(parse_f: Parser(fn(a) -&gt; b, c), parse_a: Parser(a, c)) -&gt; Parser(\n  b,\n  c,\n)\n\nSynonyms:\nnibble.keep\nnibble keep","url":"nibble.html#keep"},{"doc":"nibble","title":"lazy","content":"pub fn lazy(parser: fn() -&gt; Parser(a, b)) -&gt; Parser(a, b)\n\nSynonyms:\nnibble.lazy\nnibble lazy","url":"nibble.html#lazy"},{"doc":"nibble","title":"loop","content":"pub fn loop(init: a, step: fn(a) -&gt; Parser(Loop(b, a), c)) -&gt; Parser(\n  b,\n  c,\n)\n\nSynonyms:\nnibble.loop\nnibble loop","url":"nibble.html#loop"},{"doc":"nibble","title":"many","content":"pub fn many(parser: Parser(a, b), separator: Parser(c, b)) -&gt; Parser(\n  List(a),\n  b,\n)\n\nSynonyms:\nnibble.many\nnibble many","url":"nibble.html#many"},{"doc":"nibble","title":"map","content":"pub fn map(parser: Parser(a, b), f: fn(a) -&gt; c) -&gt; Parser(c, b)\n\nSynonyms:\nnibble.map\nnibble map","url":"nibble.html#map"},{"doc":"nibble","title":"one_of","content":"pub fn one_of(parsers: List(Parser(a, b))) -&gt; Parser(a, b)\n\nSynonyms:\nnibble.one_of\nnibble one_of","url":"nibble.html#one_of"},{"doc":"nibble","title":"replace","content":"pub fn replace(parser: Parser(a, b), with b: c) -&gt; Parser(c, b)\n\nSynonyms:\nnibble.replace\nnibble replace","url":"nibble.html#replace"},{"doc":"nibble","title":"run","content":"pub fn run(src: String, parser: Parser(a, b)) -&gt; Result(\n  a,\n  List(DeadEnd(b)),\n)\n\nSynonyms:\nnibble.run\nnibble run","url":"nibble.html#run"},{"doc":"nibble","title":"spaces","content":"pub fn spaces() -&gt; Parser(Nil, a)\n\nSynonyms:\nnibble.spaces\nnibble spaces","url":"nibble.html#spaces"},{"doc":"nibble","title":"string","content":"pub fn string(str: String) -&gt; Parser(Nil, a)\n\nSynonyms:\nnibble.string\nnibble string","url":"nibble.html#string"},{"doc":"nibble","title":"succeed","content":"pub fn succeed(a: a) -&gt; Parser(a, b)\n\nSynonyms:\nnibble.succeed\nnibble succeed","url":"nibble.html#succeed"},{"doc":"nibble","title":"take_if","content":"pub fn take_if(predicate: fn(String) -&gt; Bool, expecting: String) -&gt; Parser(\n  String,\n  a,\n)\n\nSynonyms:\nnibble.take_if\nnibble take_if","url":"nibble.html#take_if"},{"doc":"nibble","title":"take_if_and_while","content":"pub fn take_if_and_while(predicate: fn(String) -&gt; Bool, expecting: String) -&gt; Parser(\n  String,\n  a,\n)\n\nSynonyms:\nnibble.take_if_and_while\nnibble take_if_and_while","url":"nibble.html#take_if_and_while"},{"doc":"nibble","title":"take_until","content":"pub fn take_until(predicate: fn(String) -&gt; Bool) -&gt; Parser(\n  String,\n  a,\n)\n\nSynonyms:\nnibble.take_until\nnibble take_until","url":"nibble.html#take_until"},{"doc":"nibble","title":"take_while","content":"pub fn take_while(predicate: fn(String) -&gt; Bool) -&gt; Parser(\n  String,\n  a,\n)\n\nSynonyms:\nnibble.take_while\nnibble take_while","url":"nibble.html#take_while"},{"doc":"nibble","title":"then","content":"pub fn then(parser: Parser(a, b), f: fn(a) -&gt; Parser(c, b)) -&gt; Parser(\n  c,\n  b,\n)\n\nSynonyms:\nnibble.then\nnibble then","url":"nibble.html#then"},{"doc":"nibble","title":"whitespace","content":"pub fn whitespace() -&gt; Parser(Nil, a)\n\nSynonyms:\nnibble.whitespace\nnibble whitespace","url":"nibble.html#whitespace"},{"doc":"nibble","title":"nibble","content":"","url":"nibble.html"},{"doc":"nibble/pratt","title":"Config","content":"pub opaque type Config(a, ctx)\n\n\nSynonyms:\nnibble/pratt.Config\nnibble/pratt Config","url":"nibble/pratt.html#Config"},{"doc":"nibble/pratt","title":"Operator","content":"pub opaque type Operator(a, ctx)\n\n\nSynonyms:\nnibble/pratt.Operator\nnibble/pratt Operator","url":"nibble/pratt.html#Operator"},{"doc":"nibble/pratt","title":"expression","content":"pub fn expression(one_of first: List(\n    fn(Config(a, b)) -&gt; Parser(a, b),\n  ), and_then_one_of then: List(Operator(a, b)), dropping spaces: Parser(\n    Nil,\n    b,\n  )) -&gt; Parser(a, b)\n\nSynonyms:\nnibble/pratt.expression\nnibble/pratt expression","url":"nibble/pratt.html#expression"},{"doc":"nibble/pratt","title":"infix_left","content":"pub fn infix_left(precedence: Int, operator: Parser(Nil, a), apply: fn(\n    b,\n    b,\n  ) -&gt; b) -&gt; Operator(b, a)\n\nSynonyms:\nnibble/pratt.infix_left\nnibble/pratt infix_left","url":"nibble/pratt.html#infix_left"},{"doc":"nibble/pratt","title":"infix_right","content":"pub fn infix_right(precedence: Int, operator: Parser(Nil, a), apply: fn(\n    b,\n    b,\n  ) -&gt; b) -&gt; Operator(b, a)\n\nSynonyms:\nnibble/pratt.infix_right\nnibble/pratt infix_right","url":"nibble/pratt.html#infix_right"},{"doc":"nibble/pratt","title":"postfix","content":"pub fn postfix(precedence: Int, operator: Parser(Nil, a), apply: fn(\n    b,\n  ) -&gt; b) -&gt; Operator(b, a)\n\nSynonyms:\nnibble/pratt.postfix\nnibble/pratt postfix","url":"nibble/pratt.html#postfix"},{"doc":"nibble/pratt","title":"prefix","content":"pub fn prefix(precedence: Int, operator: Parser(Nil, a), apply: fn(\n    b,\n  ) -&gt; b) -&gt; fn(Config(b, a)) -&gt; Parser(b, a)\n\nSynonyms:\nnibble/pratt.prefix\nnibble/pratt prefix","url":"nibble/pratt.html#prefix"},{"doc":"nibble/pratt","title":"sub_expression","content":"pub fn sub_expression(config: Config(a, b), precedence: Int) -&gt; Parser(\n  a,\n  b,\n)\n\nSynonyms:\nnibble/pratt.sub_expression\nnibble/pratt sub_expression","url":"nibble/pratt.html#sub_expression"},{"doc":"nibble/pratt","title":"nibble/pratt","content":"","url":"nibble/pratt.html"}]);